==> docfbe_2_3_41_70.zip: docfbe_2_3_41_70/source/TCFbEDocfbeDataLoader.h <==
/*
    TCFbEDocfbeDataLoader.h    January 14, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEDocfbeDataLoaderH
#define TCFbEDocfbeDataLoaderH
//---------------------------------------------------------------------------
#include <stdio.h>

#include "TCFbECustomDataLoader.h"
#include "TCFbETypes.h"
#include "TCFbEDocfbeCommandLineParser.h"
#include "TCFbEDataSetEx.h"
//---------------------------------------------------------------------------
class TCFbEDocfbeDataLoader : public TCFbECustomDataLoader
{
public:
    virtual __fastcall TCFbEDocfbeDataLoader(TCFbEDocfbeCommandLineParser* Parser, bool IsVerbose=false, int TotalProcess=4, int BeginProcess=1);    // RXgN^
    __fastcall ~TCFbEDocfbeDataLoader();    // fXgN^

    TCFbEDataSetEx* EstimatingData;

protected:
    virtual TTargetColumnType __fastcall TargetColumnCheck(AnsiString TargetColumnLabel, const int NeighborsSize);
    virtual void __fastcall AdoptData(TCFbEDataSetEx* BaseDataSet, TCFbEDataSetEx*& AdoptedDataSet);    // AdoptedDataSet  BaseDataSet ɍ킹ēK
    virtual bool __fastcall CompareStringList(TStrings* StringList0, TStrings* StringList1) ;    // StringList0  StringList1 r

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_3_46_82.zip: docfbe_2_3_46_82/source/TCFbEDocfbeDataLoader.h <==
/*
    TCFbEDocfbeDataLoader.h    January 14, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEDocfbeDataLoaderH
#define TCFbEDocfbeDataLoaderH
//---------------------------------------------------------------------------
#include <stdio.h>

#include "TCFbECustomDataLoader.h"
#include "TCFbETypes.h"
#include "TCFbEDocfbeCommandLineParser.h"
#include "TCFbEDataSetEx.h"
//---------------------------------------------------------------------------
class TCFbEDocfbeDataLoader : public TCFbECustomDataLoader
{
public:
    virtual __fastcall TCFbEDocfbeDataLoader(TCFbEDocfbeCommandLineParser* Parser, bool IsVerbose=false, int TotalProcess=4, int BeginProcess=1);    // RXgN^
    __fastcall ~TCFbEDocfbeDataLoader();    // fXgN^

    TCFbEDataSetEx* EstimatingData;

protected:
    virtual void __fastcall AdoptData(TCFbEDataSetEx* BaseDataSet, TCFbEDataSetEx*& AdoptedDataSet);    // AdoptedDataSet  BaseDataSet ɍ킹ēK
    virtual bool __fastcall CompareStringList(TStrings* StringList0, TStrings* StringList1) ;    // StringList0  StringList1 r
    virtual TTargetColumnType __fastcall TargetColumnCheck(TCFbECustomCommandLineParser* Parser, int TargetIndex);

private:

};
//---------------------------------------------------------------------------
#endif
